@@ -77,7 +77,7 @@
 /*
   This file is part of the "Mathematical Expression Interpreter" library.
 
-  Copyright (C) 2008-2009  EDF
+  Copyright (C) 2008-2010  EDF
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -176,7 +176,7 @@ typedef union YYSTYPE
 #line 52 "mei_parser.y"
 
     double iValue;              /* double value */
-    char sIndex[200];           /* variable, constant or function identifiant */
+    char sIndex[200];           /* variable, constant or function identifier */
     mei_node_t *nPtr;           /* node pointer */
 
 
@@ -1663,7 +1663,7 @@ yyreduce:
 
 /* Line 1455 of yacc.c  */
 #line 88 "mei_parser.y"
-    { root = (yyvsp[(1) - (1)].nPtr); return 1; ;}
+    { mei_glob_root = (yyvsp[(1) - (1)].nPtr); return 1; ;}
     break;
 
   case 4:
@@ -2134,36 +2134,36 @@ yyreturn:
  *----------------------------------------------------------------------------*/
 
 void
-yyerror(char *s)
+yyerror(const char *s)
 {
     int l;
 
-    mei_free_node(root);
-    --column;
+    mei_free_node(mei_glob_root);
+    --mei_glob_column;
 
     /* bft_printf("Warning: %s\n", s); */
     /* bft_printf("line %i column %i \n", line, column); */
 
-    BFT_REALLOC(label_list,  ierr_list+1, char*);
-    BFT_REALLOC(line_list,   ierr_list+1, int);
-    BFT_REALLOC(column_list, ierr_list+1, int);
+    BFT_REALLOC(mei_glob_label_list,  mei_glob_ierr_list+1, char*);
+    BFT_REALLOC(mei_glob_line_list,   mei_glob_ierr_list+1, int);
+    BFT_REALLOC(mei_glob_column_list, mei_glob_ierr_list+1, int);
 
     l = strlen("Warning: ") +1;
-    BFT_MALLOC(label_list[ierr_list], l, char);
-    strncpy(label_list[ierr_list], "Error: ", l);
+    BFT_MALLOC(mei_glob_label_list[mei_glob_ierr_list], l, char);
+    strncpy(mei_glob_label_list[mei_glob_ierr_list], "Error: ", l);
 
     l += strlen(s);
-    BFT_REALLOC(label_list[ierr_list], l, char);
-    strncat(label_list[ierr_list], s, l);
+    BFT_REALLOC(mei_glob_label_list[mei_glob_ierr_list], l, char);
+    strncat(mei_glob_label_list[mei_glob_ierr_list], s, l);
 
     l += strlen(" \n");
-    BFT_REALLOC(label_list[ierr_list], l, char);
-    strncat(label_list[ierr_list], " \n", l);
+    BFT_REALLOC(mei_glob_label_list[mei_glob_ierr_list], l, char);
+    strncat(mei_glob_label_list[mei_glob_ierr_list], " \n", l);
 
-    line_list[ierr_list]   = line;
-    column_list[ierr_list] = column;
+    mei_glob_line_list[mei_glob_ierr_list]   = mei_glob_line;
+    mei_glob_column_list[mei_glob_ierr_list] = mei_glob_column;
 
-    ierr_list++;
+    mei_glob_ierr_list++;
 
     return;
 }
